==> ej2-vue-spreadsheet-19.1.64.tgz: package/README.md <==
# ej2-vue-spreadsheet

The Spreadsheet is an user interactive component to organize and analyze data in tabular format with configuration options for customization. It will load data by importing an excel file or from a data source, such as RESTful JSON data services and local JavaScript object array binding. The populated data can be exported as Excel with xlsx, xls and csv formats.

![Spreadsheet](https://ej2.syncfusion.com/products/images/spreadsheet/readme.gif)

> This is a commercial product and requires a paid license for possession or use. Syncfusion’s licensed software, including this component, is subject to the terms and conditions of Syncfusion's EULA (https://www.syncfusion.com/eula/es/). To acquire a license, you can purchase one at https://www.syncfusion.com/sales/products or start a free 30-day trial here (https://www.syncfusion.com/account/manage-trials/start-trials).

> A free community license (https://www.syncfusion.com/products/communitylicense) is also available for companies and individuals whose organizations have less than $1 million USD in annual gross revenue and five or fewer developers.

## Setup

To install Spreadsheet and its dependent packages, use the following command.

```sh
npm install @syncfusion/ej2-vue-spreadsheet
```

## Resources

* [Getting Started](https://ej2.syncfusion.com/vue/documentation/spreadsheet/getting-started?lang=typescript&utm_source=npm&utm_campaign=spreadsheet)
* [View Online Demos](https://ej2.syncfusion.com/vue/demos/?utm_source=npm&utm_campaign=spreadsheet#/material/spreadsheet/default)
* [Product Page](https://www.syncfusion.com/vue-ui-components/vue-spreadsheet)

## Supported Frameworks

Spreadsheet component is also offered in following list of frameworks.

1. [Angular](https://github.com/syncfusion/ej2-angular-ui-components/tree/master/components/spreadsheet)
2. [React](https://github.com/syncfusion/ej2-react-ui-components/tree/master/components/spreadsheet)
3. [Javascript (ES5)](https://www.syncfusion.com/javascript-ui-controls/js-spreadsheet)
4. [ASP.NET Core](https://www.syncfusion.com/aspnet-core-ui-controls/spreadsheet)
5. [ASP.NET MVC](https://www.syncfusion.com/aspnet-mvc-ui-controls/spreadsheet)

## Key Features

- **Data sources** - Bind the spreadsheet component with an array of JavaScript objects or DataManager.
- **Virtualization** - Provides the option to load large amount of data without performance degradation.
- **Selection** - Provides the option to select a cell or range of cells.
- **Editing** -  Provides the options to dynamically edit a cell.
- **Formulas** - Provides built-in calculation library with predefined formulas and named range support.
- **Clipboard** - Provides the option to perform clipboard operations.
- **Cell formatting** - Provides option to customize the appearance of cells.
- **Number formatting** - Provides option to format the cell value.
- **Open** - Provides the option to open excel file in spreadsheet.
- **Save** - Provides option to save spreadsheet data as excel file.
- **Sorting:** Helps you to arrange the data to particular order in a selected range of cells.
- **Resize:** Allows you to change the row height and column width. Auto fit the rows and columns based on its content.
- **Wrap text:** Provides the option to display the large content as multiple lines in a single cell.
- **Data validation:** Provides the option to validate edited values based on data validation rules defined for a cell or range of cells.
- **Find and Replace:** Provides the option to find the data and replace it across all the sheets in Spreadsheet.
- **Protect sheet:** Provides the option to  the user actions like cell editing, row and column insertion, deletion, and resizing.
- **Borders:** Provides the option to customize cell gridlines such as color and its style for enhanced UI.
- **Show/Hide:** Provides the option to show/hide the rows, columns and sheets.
- **Insert/delete:** Provides the option to insert/delete the rows, columns and sheets.
- **Merge cells:** Provides option to can combine two or more cells located in the same row or column into a single cell.
- **Conditional formatting:** Provides option to format a cell or range of cells based on the conditions applied.
- **Clear:** Provides option to clear the content, formats, and hyperlinks applied to a cell or range of cells in a spreadsheet.
- **Aggregates:** Provides option to check the sum, average, and count for the selected cells or range in the sheet tab.
- **Picture:** Allows you to view, insert, and modify a picture in a spreadsheet with customizing options.
- **Chart:** Transforms your Spreadsheet data to an intuitive overview for better understanding and to make smart business decisions.
- **Freeze pane:** Allows users to keep the specified rows and columns always visible at the top and left side of the sheet while scrolling through the sheet.
- **PDF Export:** Allows users to save the spreadsheet data as a PDF document.
- **Password protection:** Allows users to protect the workbook with a password.
- **Multi-line editing:** Allows you to insert a line break between paragraphs of the text within a cell in a Spreadsheet.
- **Range selection helper:** Helps you to select a range or multiple ranges when editing a formula in a cell.
- **RTL** - Provides right-to-left mode which aligns content in the spreadsheet component from right to left.
- **Localization** - Provides inherent support to localize the UI.
- **Accessibility** - Provides with built-in accessibility support which helps to access all the spreadsheet component features through the keyboard, screen readers, or other assistive technology devices.

## Support

Product support is available for through following mediums.

* Creating incident in Syncfusion [Direct-trac](https://www.syncfusion.com/support/directtrac/incidents?utm_source=npm&utm_campaign=spreadsheet) support system or [Community forum](https://www.syncfusion.com/forums/essential-js2?utm_source=npm&utm_campaign=spreadsheet).
* New [GitHub issue](https://github.com/syncfusion/ej2-vue-ui-components/issues/new).
* Ask your query in Stack Overflow with tag `syncfusion`, `ej2`.

## License

Check the license detail [here](https://github.com/syncfusion/ej2-javascript-ui-controls/blob/master/license?utm_source=npm&utm_campaign=spreadsheet).

## Changelog

Check the changelog [here](https://github.com/syncfusion/ej2-vue-ui-components/blob/master/components/spreadsheet/CHANGELOG.md?utm_source=npm&utm_campaign=spreadsheet)

&copy; Copyright 2019 Syncfusion, Inc. All Rights Reserved. The Syncfusion Essential Studio license and copyright applies to this distribution.

==> ej2-vue-spreadsheet-19.2.44.tgz: package/README.md <==
# ej2-vue-spreadsheet

The [Vue Spreadsheet](https://www.syncfusion.com/vue-ui-components/vue-spreadsheet?utm_source=npm&utm_medium=listing&utm_campaign=vue-spreadsheet-npm) is an user interactive component to organize and analyze data in tabular format with configuration options for customization. It will load data by importing an excel file or from a data source, such as RESTful JSON data services and local JavaScript object array binding. The populated data can be exported as Excel with xlsx, xls and csv formats.

![Spreadsheet](https://ej2.syncfusion.com/products/images/spreadsheet/readme.gif)

> This is a commercial product and requires a paid license for possession or use. Syncfusion’s licensed software, including this component, is subject to the terms and conditions of Syncfusion's EULA (https://www.syncfusion.com/eula/es/). To acquire a license, you can purchase one at https://www.syncfusion.com/sales/products or start a free 30-day trial here (https://www.syncfusion.com/account/manage-trials/start-trials).

> A free community license (https://www.syncfusion.com/products/communitylicense) is also available for companies and individuals whose organizations have less than $1 million USD in annual gross revenue and five or fewer developers.

## Setup

To install Spreadsheet and its dependent packages, use the following command.

```sh
npm install @syncfusion/ej2-vue-spreadsheet
```

## Resources

* [Product Page](https://www.syncfusion.com/vue-ui-components/vue-spreadsheet?utm_source=npm&utm_medium=listing&utm_campaign=vue-spreadsheet-npm)
* [Getting Started](https://ej2.syncfusion.com/vue/documentation/spreadsheet/getting-started/?utm_source=npm&utm_medium=listing&utm_campaign=vue-spreadsheet-npm)
* [View Online Demos](https://ej2.syncfusion.com/vue/demos/?utm_source=npm&utm_medium=listing&utm_campaign=vue-spreadsheet-npm#/material/spreadsheet/default.html)

## Supported Frameworks

Spreadsheet component is also offered in following list of frameworks.

1. [Angular Spreadsheet](https://www.syncfusion.com/angular-ui-components/angular-spreadsheet?utm_source=npm&utm_medium=listing&utm_campaign=vue-spreadsheet-npm)
2. [React Spreadsheet](https://www.syncfusion.com/react-ui-components/react-spreadsheet?utm_source=npm&utm_medium=listing&utm_campaign=vue-spreadsheet-npm)
3. [Javascript Spreadsheet](https://www.syncfusion.com/javascript-ui-controls/js-spreadsheet?utm_source=npm&utm_medium=listing&utm_campaign=vue-spreadsheet-npm)
4. [ASP.NET Core Spreadsheet](https://www.syncfusion.com/aspnet-core-ui-controls/spreadsheet?utm_source=npm&utm_medium=listing&utm_campaign=vue-spreadsheet-npm)
5. [ASP.NET MVC Spreadsheet](https://www.syncfusion.com/aspnet-mvc-ui-controls/spreadsheet?utm_source=npm&utm_medium=listing&utm_campaign=vue-spreadsheet-npm)

## Key Features

- **Data sources** - Bind the spreadsheet component with an array of JavaScript objects or DataManager.
- **Virtualization** - Provides the option to load large amount of data without performance degradation.
- **Selection** - Provides the option to select a cell or range of cells.
- **Editing** -  Provides the options to dynamically edit a cell.
- **Formulas** - Provides built-in calculation library with predefined formulas and named range support.
- **Clipboard** - Provides the option to perform clipboard operations.
- **Cell formatting** - Provides option to customize the appearance of cells.
- **Number formatting** - Provides option to format the cell value.
- **Open** - Provides the option to open excel file in spreadsheet.
- **Save** - Provides option to save spreadsheet data as excel file.
- **Sorting:** Helps you to arrange the data to particular order in a selected range of cells.
- **Resize:** Allows you to change the row height and column width. Auto fit the rows and columns based on its content.
- **Wrap text:** Provides the option to display the large content as multiple lines in a single cell.
- **Data validation:** Provides the option to validate edited values based on data validation rules defined for a cell or range of cells.
- **Find and Replace:** Provides the option to find the data and replace it across all the sheets in Spreadsheet.
- **Protect sheet:** Provides the option to  the user actions like cell editing, row and column insertion, deletion, and resizing.
- **Borders:** Provides the option to customize cell gridlines such as color and its style for enhanced UI.
- **Show/Hide:** Provides the option to show/hide the rows, columns and sheets.
- **Insert/delete:** Provides the option to insert/delete the rows, columns and sheets.
- **Merge cells:** Provides option to can combine two or more cells located in the same row or column into a single cell.
- **Conditional formatting:** Provides option to format a cell or range of cells based on the conditions applied.
- **Clear:** Provides option to clear the content, formats, and hyperlinks applied to a cell or range of cells in a spreadsheet.
- **Aggregates:** Provides option to check the sum, average, and count for the selected cells or range in the sheet tab.
- **Picture:** Allows you to view, insert, and modify a picture in a spreadsheet with customizing options.
- **Chart:** Transforms your Spreadsheet data to an intuitive overview for better understanding and to make smart business decisions.
- **Freeze pane:** Allows users to keep the specified rows and columns always visible at the top and left side of the sheet while scrolling through the sheet.
- **PDF Export:** Allows users to save the spreadsheet data as a PDF document.
- **Password protection:** Allows users to protect the workbook with a password.
- **Multi-line editing:** Allows you to insert a line break between paragraphs of the text within a cell in a Spreadsheet.
- **Range selection helper:** Helps you to select a range or multiple ranges when editing a formula in a cell.
- **RTL** - Provides right-to-left mode which aligns content in the spreadsheet component from right to left.
- **Localization** - Provides inherent support to localize the UI.
- **Accessibility** - Provides with built-in accessibility support which helps to access all the spreadsheet component features through the keyboard, screen readers, or other assistive technology devices.

## Support

Product support is available for through following mediums.

* Creating incident in Syncfusion [Direct-trac](https://www.syncfusion.com/support/directtrac/incidents?utm_source=npm&utm_medium=listing&utm_campaign=vue-spreadsheet-npm) support system or [Community forum](https://www.syncfusion.com/forums/essential-js2?utm_source=npm&utm_medium=listing&utm_campaign=vue-spreadsheet-npm).
* New [GitHub issue](https://github.com/syncfusion/ej2-vue-ui-components/issues/new?utm_source=npm&utm_medium=listing&utm_campaign=vue-spreadsheet-npm).
* Ask your query in Stack Overflow with tag `syncfusion`, `ej2`.

## License

Check the license detail [here](https://github.com/syncfusion/ej2-javascript-ui-controls/blob/master/license?utm_source=npm&utm_medium=listing&utm_campaign=vue-spreadsheet-npm).

## Changelog

Check the changelog [here](https://github.com/syncfusion/ej2-vue-ui-components/blob/master/components/spreadsheet/CHANGELOG.md?utm_source=npm&utm_medium=listing&utm_campaign=vue-spreadsheet-npm)

&copy; Copyright 2019 Syncfusion, Inc. All Rights Reserved. The Syncfusion Essential Studio license and copyright applies to this distribution.
